bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Der Nibelunge Nôt ## 15. Aventiure
___________________________________________________ #### Aventivre wie sifrit #### verraten wart
###### 877 | ### An dem vierdem morgen | zwen vnt drizech man ### sach man ce hove riten | daz wart do chvnt getan ### gvnther dem vil richen | im were widerseit ### von lvge erwuohsen vrovn criemhilde | div allergrozzesten leit
###### 878 | ### vrlovp si namen | daz si fvr solden gan ### vnd iahen daz siz waeren | livdegeres man ### den e hete betwungen | div sifrides hant ### vnd in ce gisel brahte | in daz gvntheres lant
###### 879 | ### di boten er do grvzte | vnd hiez si sitzen gan ### ir einer sprach darvnder | herre lat vns stan ### vnze wir sagen maere | die iv enbotten sint ### ia habt ir ce vinde | daz wizzet maniger mvter chint
###### 880 | ### iv widersaget livdegast | vnd livdeger ### den ir da wilen tatet | div grozlichen ser ### di wellent zv ziv riten | mit her in diz lant ### der chvenich begonde zvrnen | do er div maere bevant
###### 881 | ### do hiez man di meinraeten | zen herbergen varn ### wi mohte sich her sifrit | do davor bewarn ### er oder ander iemen | daz si da trvgen an ### daz wart sit in selben | ce grozem leide getan
###### 882 | ### der chvnich mit sinen vrivnden | rvonende gie ### hagen von tronege | in nie geruwen lie ### noch heten ez gescheiden | genvge skveniges man ### do ne wolt et hagene | nie des tages abgegan
###### 883 | ### eines tages si sifriden | ruowende vant ### do begonde vragen | der helt von niderlant ### wi gat so tvrechliche | der chvnich vnt sine man ### daz hilf ich im imer rechen | hat im iemen iht getan
###### 884 | ### do sprach der herre gvnther | mir ist von schvlden leit ### livdegast vnd livdeger | di habent mir widerseit ### si wellent offenlichen | riten in min lant ### do sprach der degen chvne | daz sol div sifrides hant
###### 885 | ### nach allen iwern eren | mit vlize vnderstan ### ich getvn noch den daegenen | als ich han e getan ### ich gelege in wuehste | ir bverge vnd ovch ir lant ### e daz ich erwinde | des sin min hovbet iwer pfant
###### 886 | ### ir vnt iwer recken | svlt hi heime bestan ### vnd lat mich zv zin riten | mit den di ich han ### daz ich iv gerne diene | daz laz ich ivch sehen ### von mir sol iweren vienden | daz wizzet leide geschehen
###### 887 | ### so wol mich dirre maere | sprach der chvenich do ### als ob er ernstliche | der helffe waere vro ### mit valsche neig im tieffe | der vngetriwe man ### do sprach der herre sifrit | ir svlt vil chleine sorge han
###### 888 | ### do schichten si die reise | mit den chnehten dan ### sifride vnd den sinen | ce sehen was ez getan ### do hiez er sich bereiten | di von niderlant ### di sifrides recken | svchten stritechlich gewant
###### 889 | ### do sprach der starche sifrit | min vater sigemvnt ### ir svlt hi beliben | wir chomen in chvrcer stvnt ### git vns got gelveche | her wider an den rin ### ir svlt bi dem chvnige | hie vil vroliche sin
###### 890 | ### div zeichen si an bvnden | also si wolden dan ### da waren genvge | di gvntheres man ### di ne wessen niht der maere | davon ez was geschehen ### man mohte groz gesinde | do bi sifride sehen
###### 891 | ### ir helme vnd ovch ir prvenne | si bvnden vf di march ### sich bereite vome lande | vil manich ritter starch ### do gi von tronege hagene | da er criemhilde vant ### vnt bat im geben vrlovp | si wolden rvmen daz lant
###### 892 | ### nv wol mich sprach do criemhilt | daz ich ie gewan den man ### der minen lieben vrivnden | wol tar vor gestan ### also min herre sifrit | tvt den vrivnden min ### des wil ich hohes mvtes | sprach div chveneginne sin
###### 893 | ### vil lieber vrivnt hagene | gedenchet ane daz ### daz ich iv gerne diene | vnd noch nie wart gehaz ### des lazzet mich geniezen | an minem liebem man ### ern sol des niht engelten | hab ich prvnnhilde iht getan
###### 894 | ### daz hat mich sit geruowen | sprach daz edel wip ### ovch hat er darvmbe | cerbluowen minen lip ### daz ich iz ie geredete | daz beswaeret ir den mvt ### daz hat vil wol errochen | der helt chvne vnd gvt
###### 895 | ### er sprach ir wert versvenet | noch wol nach disen tagen ### criemhilt min liebiv vrowe | ia svlt ir mir sagen ### wi ich iv mvge gedienen | an sifride iwerm man ### daz tvn ich gerne vrowe | wand ich es niemen baz en gan
###### 896 | ### ich waere an alle sorge | sprach daz edel wip ### daz im iemen naeme | in stvrme sinen lip ### ob er niht wolde volgen | siner vebermvt ### so waere im sicher | der degen chvne vnd gvt
###### 897 | ### vrowe sprach do hagene | vnt habt ir des wan ### daz man in mvege versniden | ir svlt mich wizzen lan ### mit wi getanen listen | ich daz sol vndersten ### ich wil im ce hvte | immer riten vnd gen
###### 898 | ### si sprach dv bist min mach | vnd ich pin der din ### ich bevilhe dir mit triwen | den lieben wine min ### daz tv mir wol behvetest | den min holden man ### si sagt im chvendiv maere | div bezzer waeren verlan
###### 899 | ### si sprach min man ist chvene | vnt darzv starch genvch ### do er den lintrachen | an dem berge slvch ### ia badete sich in dem plvote | der reche vil gemeit ### davon in sit in stvrmen | nie dehein waffen versneit
###### 900 | ### jedoch pin ich in sorgen | swenn er in strite stat ### vnd vil der gershvezze | von helden hande gat ### daz ich da verliese | den minen lieben man ### hey waz ich grozzer sorge | diche vmbe sifriden han
###### 901 | ### ich meld iz vf genade | vil lieber vrivnt ### daz dv dine triwe | behaltest ane mir ### da man da mach verhowen | den minen lieben man ### daz laz ich dich hoeren | deist vf genade getan
###### 902 | ### do von des trachen wunden | vloz daz heize blvt ### vnd sich darinne badete | der chvene ritter gvt ### do viel im zwihssen di herte | ein lindenblat vil breit ### da mach man in versniden | des ist mir sorgen vil bereit
###### 903 | ### do sprach von tronege hagene | vf daz sin gewant ### naet ir im ein chleinez ceichen | da ist mir bi bechant ### wa ich in mvege behevten | so wir in stvrme stan ### si wanden helt do vristen | ez was vf sinen tot getan
###### 904 | ### si sprach mit chleinen siden | nae ich vf sin gewant ### ein tovgenlichez crvece | da sol helt din hant ### den minen man behivten | so ez an di herte gat ### swenn er in den stvermen | vor sinen vienden stat
###### 905 | ### daz tvn ich sprach do hagene | vil liebiv vrowe min ### do wand ovch des div vrowe | ez sold im vrvme sin ### do was damit verraten | der criemhilde man ### vrlovp nam do hagene | do gie er vroeliche dan
###### 906 | ### des chveneges ingesinde | was alliz samt gemvt ### ich waene immer recke | mer deheiner tvt ### so grozer meinraete | so da von im ergie ### do sich an sine triwe | criemhilt div chveneginne lie
###### 907 | ### des andern morgens | mit tvsent siner man ### reit der herre sifrit | vil vroelichen dan ### er wand er solde rechen | der siner vrivnde leit ### hagen im reit so nahen | daz er geschowete div chleit
###### 908 | ### als er gesach daz pilde | do schiet er tovgen dan ### di sageten ander maere | zwene siner man ### mit vride solde beliben | daz gvntheres lant ### vnd si hete livdger | zv dem chvenige gesant
###### 909 | ### wi vngerne sifrit | do hin wider reit ### ern het etewaz errochen | siner vrivnde leit ### wand in vil chvm erwanden | di gvntheres man ### do reit er zv dem kvenige | der wirt im danchen began
###### 910 | ### nv lon iv got des willen | vrivnt sifrit ### daz ir so willechliche | tvt des ich ivch bit ### daz sol ich immer dienen | als ich von rehte sol ### vor allen minen vrivnden | so getruwe ich iv wol
###### 911 | ### nv wir der herverte | ledich worden sin ### so wil ich iagen riten | bern vnd swin ### hin cem waschemwalde | als ich vil dike han getan ### daz het geraten hagene | der vil vngetriwe man
###### 912 | ### allen minen gesten | sol man daz sagen ### daz wir vil vrv riten | di wellen mit mir iagen ### daz si sich bereiten | di aber hie bestan ### hovhssen mit den vrowen | daz si mir liebe getan
###### 913 | ### do sprach der herre sifrit | mit herlichem site ### swenne ir iagen ritet | da wil ich gerne mite ### so svlt ir mir lihen | einen svcheman ### vnd etelichen bracken | so wil ich riten in den tan
###### 914 | ### welt ir niht nemen einen | sprach der kvenich cehant ### ich lih iv welt ir viere | den vil wol ist bechant ### der walt vnde ovch di stige | da div tier hine gant ### die ivch niht fverwise | cen herbergen riten lant
###### 915 | ### do reit zv sinem wibe | der recke vil gemeit ### schiere hete hagene | dem kvenige geseit ### wir gewinnen wol | den tiwerlichen degen ### svs getaner vntriwe | solde niemer man gepflegen

<<< Übersicht <<< vorige Seite nächste Seite >>>